//Below demonstrates how to create a unique custom action/ability for the Battle Mod.

local BattleFuncSet = false //We're going to use this to check and see if BattleMod has been added to the game yet.

addHook("ThinkFrame",function()
	//First make sure the necessary tables exist.
	if not(BattleFuncSet) and CBW_Battle and CBW_Battle.ActionChar then //CBW_Battle.ActionChar is a table which stores all of the characters' special ability functions. While you can't safely call on CBW_Battle's functions directly if BattleMod isn't loaded, you can define and store a function here which BattleMod will run when CBW_Battle.ActionChar[<yourskin>] is read by the game.
		BattleFuncSet = true //Flip on, so that we don't run this script again in the future.
		//Let's create an action we might want the player to perform later
		local function ThrowBomb(mo)
			local bomb = P_SPMAngle(mo,MT_FBOMB,mo.angle,0,0)
			if bomb and bomb.valid then
				P_SetObjectMomZ(bomb,FRACUNIT*8,true)
			end
		end
		
		//Now create a function that BattleMod will read.
		CBW_Battle.ActionChar["eggrobo"] = function(mo,doaction,pressedaction) //BattleMod will refer to this function whenever the player skin is "eggrobo".
			//Function arguments:
			//'mo' is the player object in question.
			//'doaction' is 1 if the player is pressing the action key, and 2 if they are holding it down; 0 if neither, and -1 if the player is attempting but unable to perform an action.
			//'pressedaction' is almost the same as doaction, except it will ALWAYS return the player's action key input, regardless of whether the player can perform an action or not.
			mo.player.actiontext = "Throw Bomb" //HUD display text for this action type. This can be changed freely during runtime to display different text under different circumstances.
			mo.player.actionstate = 0 //Action State. 0 is neutral; generally the game will leave this alone except when the player is respawning or changing skins. Scripters can use this to define when characters are in certain phases of their ability.
			mo.player.actiontime = 0 //Generally used as a ticcounter to keep track of how long the player has been in a certain actionstate. However, this actually does nothing on its own and is freely modifiable. It will not tic upward or downward unless specified by the scripter.
			mo.player.actionrings = 10 //The amount of rings your special action costs. This number will show up in the HUD, unless that number is "0".
-- 	 		mo.player.disableringslinger = true //This prevents players from being able to fire rings. This is usually not needed in scripts since BattleMod already sets the variable to true on skin load. However, some characters, like Fang, may need this to be manually set to "false" for whatever reason, so I've included it here for posterity.
			if doaction == 1 then //We have pressed the action button.
				if mo.player.rings >= mo.player.actionrings //Action ring requirements
					mo.player.spendrings = 1 //Signal to BattleMod to spend rings (as specified by mo.player.actionrings).
					ThrowBomb(mo) //Perform the action.
					mo.player.actioncooldown = TICRATE // This constantly tics down to 0 and is used for regulating player actions.
				else //We have not met the action ring requirements.
					mo.player.spendrings = -1  //Signal to BattleMod that the player attempted and failed to perform an action.
				end
			end
		end	
		print("EggRobo BattleMod action has been loaded.") //That extra bit of confirmation is always nice. If this spams the console continuously, however, then we know we have a problem!
	end
end)

/* Other notes:

If you're not feeling up to the task of making a new special ability, you can easily use one of the pre-existing abilities for the six vanilla characters by executing the following block of text:
	if CBW_Battle and CBW_Battle.ActionChar then
		CBW_Battle.ActionChar["eggrobo"] = CBW_Battle.ActionChar["tails"]
	end
It's as simple as that! This will make it so that the skin "EggRobo" performs Tails' special ability, which summons a buzz sentry.


Note that doaction will always return -1 if the button was just pressed while:
- The player is exiting the level
- The player's action is on cooldown
- The player character is in pain
- The player's controls have been disabled
- The player is "not it" in tag mode
- The player has the flag in CTF
If you need to read action inputs during any of these moments, use the third function argument, 'pressedaction', to get the player's true inputs.


Need to make sure a character's lua script isn't conflicting with BattleMod's tagmode? Check for either 'player.iseggrobo' or 'CBW_BattleMod and player.pflags&PF_TAGIT'

*/